==> zio-aws-ses_2.12-5.17.130.1-sources.jar: zio/aws/ses/model/EventDestination.scala <==
package zio.aws.ses.model
import zio.aws.ses.model.primitives.{Enabled, EventDestinationName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class EventDestination(
    name: EventDestinationName,
    enabled: Option[Enabled] = None,
    matchingEventTypes: Iterable[zio.aws.ses.model.EventType],
    kinesisFirehoseDestination: Option[
      zio.aws.ses.model.KinesisFirehoseDestination
    ] = None,
    cloudWatchDestination: Option[zio.aws.ses.model.CloudWatchDestination] =
      None,
    snsDestination: Option[zio.aws.ses.model.SNSDestination] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ses.model.EventDestination = {
    import EventDestination.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ses.model.EventDestination
      .builder()
      .name(EventDestinationName.unwrap(name): java.lang.String)
      .optionallyWith(
        enabled.map(value => Enabled.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .matchingEventTypesWithStrings(matchingEventTypes.map { item =>
        item.unwrap.toString
      }.asJavaCollection)
      .optionallyWith(
        kinesisFirehoseDestination.map(value => value.buildAwsValue())
      )(_.kinesisFirehoseDestination)
      .optionallyWith(
        cloudWatchDestination.map(value => value.buildAwsValue())
      )(_.cloudWatchDestination)
      .optionallyWith(snsDestination.map(value => value.buildAwsValue()))(
        _.snsDestination
      )
      .build()
  }
  def asReadOnly: zio.aws.ses.model.EventDestination.ReadOnly =
    zio.aws.ses.model.EventDestination.wrap(buildAwsValue())
}
object EventDestination {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ses.model.EventDestination
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ses.model.EventDestination =
      zio.aws.ses.model.EventDestination(
        name,
        enabled.map(value => value),
        matchingEventTypes,
        kinesisFirehoseDestination.map(value => value.asEditable),
        cloudWatchDestination.map(value => value.asEditable),
        snsDestination.map(value => value.asEditable)
      )
    def name: EventDestinationName
    def enabled: Option[Enabled]
    def matchingEventTypes: List[zio.aws.ses.model.EventType]
    def kinesisFirehoseDestination
        : Option[zio.aws.ses.model.KinesisFirehoseDestination.ReadOnly]
    def cloudWatchDestination
        : Option[zio.aws.ses.model.CloudWatchDestination.ReadOnly]
    def snsDestination: Option[zio.aws.ses.model.SNSDestination.ReadOnly]
    def getName: ZIO[Any, Nothing, EventDestinationName] = ZIO.succeed(name)
    def getEnabled: ZIO[Any, AwsError, Enabled] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getMatchingEventTypes
        : ZIO[Any, Nothing, List[zio.aws.ses.model.EventType]] =
      ZIO.succeed(matchingEventTypes)
    def getKinesisFirehoseDestination: ZIO[
      Any,
      AwsError,
      zio.aws.ses.model.KinesisFirehoseDestination.ReadOnly
    ] = AwsError.unwrapOptionField(
      "kinesisFirehoseDestination",
      kinesisFirehoseDestination
    )
    def getCloudWatchDestination
        : ZIO[Any, AwsError, zio.aws.ses.model.CloudWatchDestination.ReadOnly] =
      AwsError.unwrapOptionField("cloudWatchDestination", cloudWatchDestination)
    def getSnsDestination
        : ZIO[Any, AwsError, zio.aws.ses.model.SNSDestination.ReadOnly] =
      AwsError.unwrapOptionField("snsDestination", snsDestination)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ses.model.EventDestination
  ) extends zio.aws.ses.model.EventDestination.ReadOnly {
    override val name: EventDestinationName =
      zio.aws.ses.model.primitives.EventDestinationName(impl.name())
    override val enabled: Option[Enabled] = scala
      .Option(impl.enabled())
      .map(value => zio.aws.ses.model.primitives.Enabled(value))
    override val matchingEventTypes: List[zio.aws.ses.model.EventType] = impl
      .matchingEventTypes()
      .asScala
      .map { item =>
        zio.aws.ses.model.EventType.wrap(item)
      }
      .toList
    override val kinesisFirehoseDestination
        : Option[zio.aws.ses.model.KinesisFirehoseDestination.ReadOnly] = scala
      .Option(impl.kinesisFirehoseDestination())
      .map(value => zio.aws.ses.model.KinesisFirehoseDestination.wrap(value))
    override val cloudWatchDestination
        : Option[zio.aws.ses.model.CloudWatchDestination.ReadOnly] = scala
      .Option(impl.cloudWatchDestination())
      .map(value => zio.aws.ses.model.CloudWatchDestination.wrap(value))
    override val snsDestination
        : Option[zio.aws.ses.model.SNSDestination.ReadOnly] = scala
      .Option(impl.snsDestination())
      .map(value => zio.aws.ses.model.SNSDestination.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ses.model.EventDestination
  ): zio.aws.ses.model.EventDestination.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ses_2.13-5.19.31.3-sources.jar: zio/aws/ses/model/EventDestination.scala <==
package zio.aws.ses.model
import zio.aws.ses.model.primitives.{Enabled, EventDestinationName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EventDestination(
    name: EventDestinationName,
    enabled: Optional[Enabled] = Optional.Absent,
    matchingEventTypes: Iterable[zio.aws.ses.model.EventType],
    kinesisFirehoseDestination: Optional[
      zio.aws.ses.model.KinesisFirehoseDestination
    ] = Optional.Absent,
    cloudWatchDestination: Optional[zio.aws.ses.model.CloudWatchDestination] =
      Optional.Absent,
    snsDestination: Optional[zio.aws.ses.model.SNSDestination] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ses.model.EventDestination = {
    import EventDestination.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ses.model.EventDestination
      .builder()
      .name(EventDestinationName.unwrap(name): java.lang.String)
      .optionallyWith(
        enabled.map(value => Enabled.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .matchingEventTypesWithStrings(matchingEventTypes.map { item =>
        item.unwrap.toString
      }.asJavaCollection)
      .optionallyWith(
        kinesisFirehoseDestination.map(value => value.buildAwsValue())
      )(_.kinesisFirehoseDestination)
      .optionallyWith(
        cloudWatchDestination.map(value => value.buildAwsValue())
      )(_.cloudWatchDestination)
      .optionallyWith(snsDestination.map(value => value.buildAwsValue()))(
        _.snsDestination
      )
      .build()
  }
  def asReadOnly: zio.aws.ses.model.EventDestination.ReadOnly =
    zio.aws.ses.model.EventDestination.wrap(buildAwsValue())
}
object EventDestination {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ses.model.EventDestination
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ses.model.EventDestination =
      zio.aws.ses.model.EventDestination(
        name,
        enabled.map(value => value),
        matchingEventTypes,
        kinesisFirehoseDestination.map(value => value.asEditable),
        cloudWatchDestination.map(value => value.asEditable),
        snsDestination.map(value => value.asEditable)
      )
    def name: EventDestinationName
    def enabled: Optional[Enabled]
    def matchingEventTypes: List[zio.aws.ses.model.EventType]
    def kinesisFirehoseDestination
        : Optional[zio.aws.ses.model.KinesisFirehoseDestination.ReadOnly]
    def cloudWatchDestination
        : Optional[zio.aws.ses.model.CloudWatchDestination.ReadOnly]
    def snsDestination: Optional[zio.aws.ses.model.SNSDestination.ReadOnly]
    def getName: ZIO[Any, Nothing, EventDestinationName] = ZIO.succeed(name)
    def getEnabled: ZIO[Any, AwsError, Enabled] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getMatchingEventTypes
        : ZIO[Any, Nothing, List[zio.aws.ses.model.EventType]] =
      ZIO.succeed(matchingEventTypes)
    def getKinesisFirehoseDestination: ZIO[
      Any,
      AwsError,
      zio.aws.ses.model.KinesisFirehoseDestination.ReadOnly
    ] = AwsError.unwrapOptionField(
      "kinesisFirehoseDestination",
      kinesisFirehoseDestination
    )
    def getCloudWatchDestination
        : ZIO[Any, AwsError, zio.aws.ses.model.CloudWatchDestination.ReadOnly] =
      AwsError.unwrapOptionField("cloudWatchDestination", cloudWatchDestination)
    def getSnsDestination
        : ZIO[Any, AwsError, zio.aws.ses.model.SNSDestination.ReadOnly] =
      AwsError.unwrapOptionField("snsDestination", snsDestination)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ses.model.EventDestination
  ) extends zio.aws.ses.model.EventDestination.ReadOnly {
    override val name: EventDestinationName =
      zio.aws.ses.model.primitives.EventDestinationName(impl.name())
    override val enabled: Optional[Enabled] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => zio.aws.ses.model.primitives.Enabled(value))
    override val matchingEventTypes: List[zio.aws.ses.model.EventType] = impl
      .matchingEventTypes()
      .asScala
      .map { item =>
        zio.aws.ses.model.EventType.wrap(item)
      }
      .toList
    override val kinesisFirehoseDestination
        : Optional[zio.aws.ses.model.KinesisFirehoseDestination.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.kinesisFirehoseDestination())
        .map(value => zio.aws.ses.model.KinesisFirehoseDestination.wrap(value))
    override val cloudWatchDestination
        : Optional[zio.aws.ses.model.CloudWatchDestination.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cloudWatchDestination())
        .map(value => zio.aws.ses.model.CloudWatchDestination.wrap(value))
    override val snsDestination
        : Optional[zio.aws.ses.model.SNSDestination.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.snsDestination())
        .map(value => zio.aws.ses.model.SNSDestination.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ses.model.EventDestination
  ): zio.aws.ses.model.EventDestination.ReadOnly = new Wrapper(impl)
}
